@@ -734,7 +734,7 @@ class account():
             note.destroy()
             return False
 
-    def FollowUser(name):
+    def FollowUser(self, widget, name, *args):
         #strip out the @ which isn't really part of the username
         name = name.replace("@", "")
         print "follow: " + name
@@ -762,7 +762,7 @@ class account():
             note.system_note_dialog(msg)
             print msg
 
-    def UnFollowUser(name):
+    def UnFollowUser(self, widget, name, *args):
         #strip out the @ which isn't really part of the username
         name = name.replace("@", "")
         print "follow: " + name
@@ -770,7 +770,7 @@ class account():
                 print "using oauth to unfollow"
                 data = self.api.DestroyFriendship(name)
                 note = osso.SystemNote(self.osso_c)
-                result = note.system_note_infoprint("Now following " + name)
+                result = note.system_note_infoprint("No longer following " + name)
         except IOError, e:
             print "error"
             msg = 'Error unfollowing ' + name + ' '
